@@ -55,9 +55,7 @@ additions to C<Params::Util> may clash)
 
 =cut
 
-BEGIN {
-	require 5.004;
-}
+use 5.005;
 use strict;
 use overload     ();
 use Exporter     ();
@@ -65,13 +63,13 @@ use Scalar::Util ();
 
 use vars qw{$VERSION @ISA @EXPORT_OK %EXPORT_TAGS};
 BEGIN {
-	$VERSION   = '0.29';
+	$VERSION   = '0.33';
 	@ISA       = 'Exporter';
 
 	@EXPORT_OK = qw{
 		_STRING     _IDENTIFIER
 		_CLASS      _CLASSISA   _SUBCLASS  _DRIVER
-		_POSINT     _NONNEGINT
+		_NUMBER     _POSINT     _NONNEGINT
 		_SCALAR     _SCALAR0
 		_ARRAY      _ARRAY0     _ARRAYLIKE
 		_HASH       _HASH0      _HASHLIKE
@@ -208,6 +206,28 @@ sub _SUBCLASS ($$) {
 
 =pod
 
+=head2 _NUMBER $scalar
+
+The C<_NUMBER> function is intended to be imported into your
+package, and provides a convenient way to test to see if a value is
+a number. That is, it is defined and perl thinks it's a number.
+
+This function is basically a Params::Util-style wrapper around the
+L<Scalar::Util> C<looks_like_number> function.
+
+Returns the value as a convience, or C<undef> if the value is not a
+number.
+
+=cut
+
+sub _NUMBER ($) {
+	( defined $_[0] and ! ref $_[0] and Scalar::Util::looks_like_number($_[0]) )
+	? $_[0]
+	: undef;
+}
+
+=pod
+
 =head2 _POSINT $integer
 
 The C<_POSINT> function is intended to be imported into your
@@ -479,12 +499,6 @@ sub _CODELIKE {
 	? $_[0] : undef;
 }
 
-# Will stay around until end-2006 with a warning, then will be deleted.
-sub _CALLABLE {
-	warn "_CALLABLE has been deprecated. Change to _CODELIKE";
-	_CODELIKE(@_);
-}
-
 =pod
 
 =head2 _INVOCANT $value
@@ -721,7 +735,7 @@ L<Params::Validate>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2005, 2006 Adam Kennedy.
+Copyright 2005  - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
